==> haskell-hslua-1.0.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 1.0.2
id: hslua-1.0.2-D3KLaZ8EEFtDGboILpzxA3
key: hslua-1.0.2-D3KLaZ8EEFtDGboILpzxA3
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2019 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
homepage: https://hslua.github.io/
synopsis: Bindings to Lua, an embeddable scripting language
description:
    HsLua provides bindings, wrappers, types, and helper
    functions to bridge Haskell and <https://www.lua.org/ Lua>.
    .
    This package contains a full Lua interpreter version 5.3.5.
    If you want to link it with a system-wide Lua installation,
    use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: bc69e13a26b14578ffefb14f5f9382bb
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Core Foreign.Lua.Core.Constants
    Foreign.Lua.Core.Error Foreign.Lua.Core.RawBindings
    Foreign.Lua.Core.Types Foreign.Lua.FunctionCalling
    Foreign.Lua.Types Foreign.Lua.Types.Peekable
    Foreign.Lua.Types.Pushable Foreign.Lua.Userdata Foreign.Lua.Util
hidden-modules: Foreign.Lua.Utf8 Foreign.Lua.Core.Auxiliary
                Foreign.Lua.Core.Functions
import-dirs: /usr/lib/ghc-8.6.4/site-local/hslua-1.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hslua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hslua-1.0.2
hs-libraries: HShslua-1.0.2-D3KLaZ8EEFtDGboILpzxA3
extra-libraries:
    lua m
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.0-HSEN1HsF9E42usfcjSNYsT mtl-2.2.2 text-1.2.3.1
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-1.0.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 1.0.2
id: hslua-1.0.2-7qYUI7LLgN8AwSwv0KlCQ5
key: hslua-1.0.2-7qYUI7LLgN8AwSwv0KlCQ5
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2019 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
homepage: https://hslua.github.io/
synopsis: Bindings to Lua, an embeddable scripting language
description:
    HsLua provides bindings, wrappers, types, and helper
    functions to bridge Haskell and <https://www.lua.org/ Lua>.
    .
    This package contains a full Lua interpreter version 5.3.5.
    If you want to link it with a system-wide Lua installation,
    use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: c389f20125f65f8ff4fa7578f370e3d5
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Core Foreign.Lua.Core.Constants
    Foreign.Lua.Core.Error Foreign.Lua.Core.RawBindings
    Foreign.Lua.Core.Types Foreign.Lua.FunctionCalling
    Foreign.Lua.Types Foreign.Lua.Types.Peekable
    Foreign.Lua.Types.Pushable Foreign.Lua.Userdata Foreign.Lua.Util
hidden-modules: Foreign.Lua.Utf8 Foreign.Lua.Core.Auxiliary
                Foreign.Lua.Core.Functions
import-dirs: /usr/lib/ghc-8.6.4/site-local/hslua-1.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hslua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hslua-1.0.2
hs-libraries: HShslua-1.0.2-7qYUI7LLgN8AwSwv0KlCQ5
extra-libraries:
    lua m
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.1-7nkghZ77rTO8NZKanvk3XU mtl-2.2.2 text-1.2.3.1
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
